Internal main preparation function for bfpca
bfpca_argPreparation(
Y,
Kt,
time,
t_min,
t_max,
periodic,
seed,
subsample,
verbose
)List with elements knots, Theta_phi, xi,
alpha_coefs.
Internal objects created in bfpca.
Number of B-spline basis functions used to estimate mean functions
and functional principal components. Default is 8. If npc_varExplained
is used, Kt is set to 20.
If TRUE, uses periodic b-spline basis functions. Default is FALSE.
Set seed for reproducibility. Defaults to 1988.
if the number of rows of the data is greater than 10 million rows, the `id` values are subsampled to get the mean coefficients.
Can be set to integers between 0 and 4 to control the level of detail of the printed diagnostic messages. Higher numbers lead to more detailed messages. Defaults to 1.