Loss function for registration step optimization
loss_h(
Y,
Theta_h,
mean_coefs,
knots,
beta.inner,
family,
t_min,
t_max,
parametric_warps = FALSE
)The scalar value taken by the loss function.
vector of observed points.
B-spline basis for inverse warping functions.
spline coefficient vector for mean curve.
knot locations for B-spline basis used to estimate mean and FPC basis function.
spline coefficient vector to be estimated for warping function h.
gaussian or binomial.
minimum value to be evaluated on the time domain.
maximum value to be evaluated on the time domain.
If FALSE (default), inverse warping functions are estimated nonparametrically. If 'beta_cdf', they are assumed to have the form of a Beta(a,b) CDF. If 'piecewise' they follow a piecewise parameterized function.