Gradient of loss function for registration step
loss_h_gradient(
Y,
Theta_h,
mean_coefs,
knots,
beta.inner,
family = "gaussian",
t_min,
t_max
)A numeric vector of spline coefficients for the gradient of the loss function.
vector of observed points.
B-spline basis for inverse warping functions.
spline coefficient vector for mean curve.
knot locations for B-spline basis used to estimate mean and FPC basis function.
spline coefficient vector to be estimated for warping function h.
gaussian or binomial.
minimum value to be evaluated on the time domain.
maximum value to be evaluated on the time domain.
Julia Wrobel jw3134@cumc.columbia.edu