This function simulates unregistered curves, providing the time values for both the unregistered curves (t_star) and the registered curves (t). Curves all have one peak, the location of which is shifted on the unregistered domain, meant to mimic accelerometer data.
simulate_unregistered_curves(
I = 50,
D = 100,
lambda = 15,
seed = 1988,
period = 2 * pi,
spline_based = FALSE,
phase_variation = TRUE
)A simulated dataframe with variables id, value, index, latent_mean, and t. Index is the domain on which curves are unregistered and t is the domain on which curves are registered.
Number of subjects. Defaults is 50.
Number of grid points per subject. Default is 100.
Standard deviation for subject-specific amplitudes.
Seed for reproducibility. Default is 1988.
Controls the period of the mean curve
If FALSE curve is constructed using sine and cosine functions, if TRUE, curve is constructed using B-spline basis.
If TRUE, creates phase variation (registered curves are observed on uneven grid). If FALSE, no phase variation.
Julia Wrobel julia.wrobel@cuanschutz.edu, Jeff Goldsmith ajg2202@cumc.columbia.edu